@@ -16,17 +16,26 @@
 These exceptions are so general purpose that they don't belong in Zope
 application-specific packages.
 """
-from zope.exceptions.interfaces import DuplicationError, IDuplicationError
-from zope.exceptions.interfaces import UserError, IUserError
+from zope.exceptions.interfaces import DuplicationError
+from zope.exceptions.interfaces import IDuplicationError
+from zope.exceptions.interfaces import UserError
+from zope.exceptions.interfaces import IUserError
+
+from zope.exceptions.exceptionformatter import format_exception
+from zope.exceptions.exceptionformatter import print_exception
+from zope.exceptions.exceptionformatter import extract_stack
 
 # avoid dependency on zope.security:
 try:
     import zope.security
-except ImportError, v:
+except ImportError as v: #pragma NO COVER
     # "ImportError: No module named security"
-    if not str(v).endswith(' security'):
+    if not str(v).endswith('security'):
         raise
-else:
-    from zope.security.interfaces import IUnauthorized, Unauthorized
-    from zope.security.interfaces import IForbidden, IForbiddenAttribute
-    from zope.security.interfaces import Forbidden, ForbiddenAttribute
+else: #pragma NO COVER
+    from zope.security.interfaces import IUnauthorized
+    from zope.security.interfaces import Unauthorized
+    from zope.security.interfaces import IForbidden
+    from zope.security.interfaces import IForbiddenAttribute
+    from zope.security.interfaces import Forbidden
+    from zope.security.interfaces import ForbiddenAttribute
